( cd usr/openwin/lib ; rm -rf libolgx.so.3 )
( cd usr/openwin/lib ; ln -sf libolgx.so.3.2.0 libolgx.so.3 )
( cd usr/openwin/lib ; rm -rf libxview.so.3 )
( cd usr/openwin/lib ; ln -sf libxview.so.3.2.0 libxview.so.3 )
